---
title: <span class="badge builder"></span> ResourceGroupsQuery
---
# <span class="badge builder"></span> ResourceGroupsQuery

## Constructor

```python
ResourceGroupsQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> azuremonitor.ResourceGroupsQuery
```

### <span class="badge object-method"></span> raw_query

```python
def raw_query(raw_query: str) -> typing.Self
```

### <span class="badge object-method"></span> subscription

```python
def subscription(subscription: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ResourceGroupsQuery](./object-ResourceGroupsQuery.md)
